@@ -105,7 +105,7 @@ class MongoDbUtil(object):
                                               via the Python API.
 
         Returns:
-            bool: True for sucess or false otherwise
+            bool: True for success or False otherwise
         """
         try:
             if overWrite and self.collectionExists(databaseName, collectionName):
@@ -113,6 +113,28 @@ class MongoDbUtil(object):
             #
             ok = self.__mgObj[databaseName].create_collection(collectionName)
             logger.debug("Return from create collection %r", ok)
+            if bsonSchema:
+                self.updateCollection(databaseName, collectionName, bsonSchema=bsonSchema, validationLevel=validationLevel, validationAction=validationAction)
+            return True
+        except Exception as e:
+            logger.exception("Failing for databaseName %s collectionName %s with %s", databaseName, collectionName, str(e))
+        return False
+
+    def updateCollection(self, databaseName, collectionName, bsonSchema=None, validationLevel="strict", validationAction="error"):
+        """ Update the validation schema and validation settings for the input collection
+        Args:
+            databaseName (str): Description
+            collectionName (str): Description
+            bsonSchema (dict, optional): JSON Schema (MongoDb flavor ~Draft 4 semantics w/ BSON types)
+            validationLevel (str, optional): Apply to all inserts (strict) of but not for updates to existing documents (moderate)
+            validationAction (str, optional): Reject inserts with error (error) or allow inserts with logged warning (warn)
+                                              Warnings are recorded in the MongoDB system log and these are not conveniently accessible
+                                              via the Python API.
+
+        Returns:
+            bool: True for success or False otherwise
+        """
+        try:
             if bsonSchema:
                 # bsonSchema.update({'additionalProperties': False})
                 sD = {"$jsonSchema": bsonSchema}
@@ -209,7 +231,7 @@ class MongoDbUtil(object):
                 rId = self.insert(databaseName, collectionName, dD, documentKey=kyVals)
                 if rId:
                     rIdL.append(rId)
-                    logger.debug("Insert suceeds for document %s", (kyVals,))
+                    logger.debug("Insert succeeds for document %s", (kyVals,))
                 else:
                     logger.debug("Loading document %r failed", (kyVals,))
         except Exception as e:
@@ -246,7 +268,7 @@ class MongoDbUtil(object):
             logger.exception("Failing with %s", str(e))
         return None
 
-    def update(self, databaseName, collectionName, dObj, selectD):
+    def update(self, databaseName, collectionName, dObj, selectD, upsertFlag=False):
         """ Update documents satisfying the selection details with the content of dObj.
 
         Args:
@@ -263,7 +285,7 @@ class MongoDbUtil(object):
         try:
             numModified = 0
             clt = self.__mgObj[databaseName].get_collection(collectionName)
-            rV = clt.update_many(selectD, {"$set": dObj}, upsert=False, array_filters=None)
+            rV = clt.update_many(selectD, {"$set": dObj}, upsert=upsertFlag, array_filters=None)
             try:
                 numMatched = rV.matched_count
                 numModified = rV.modified_count
@@ -304,7 +326,7 @@ class MongoDbUtil(object):
                 logger.error("Failing %s and %s selectD %r with %s", databaseName, collectionName, selectD, str(e))
                 return None
         except Exception as e:
-            logger.exception("Failing %s and %s selectD %r with %s", databaseName, collectionName, selectD, str(e))
+            logger.error("Failing %s and %s selectD %r with %s", databaseName, collectionName, selectD, str(e))
         return None
 
     def replaceList(self, databaseName, collectionName, dList, keyNames, upsertFlag=True):
@@ -375,6 +397,30 @@ class MongoDbUtil(object):
         #
         return delTupL
 
+    def delete(self, databaseName, collectionName, selectD):
+        """Delete objects from the input collection based on the input selection query.
+
+
+        Args:
+            databaseName (str): Target database name
+            collectionName (str): Target collection name
+            selectD (dict): selection query
+
+        Returns:
+            (int): deletion count
+
+        """
+        delCount = 0
+        try:
+            clt = self.__mgObj[databaseName].get_collection(collectionName)
+            rV = clt.delete_many(selectD)
+            delCount = rV.deleted_count
+            logger.debug("%s %s deleted %d", databaseName, collectionName, delCount)
+        except Exception as e:
+            logger.error("Failing %s and %s selectD %r with %s", databaseName, collectionName, selectD.items(), str(e))
+        #
+        return delCount
+
     def createIndex(self, databaseName, collectionName, keyList, indexName="primary", indexType="DESCENDING", uniqueFlag=False):
 
         try:
